@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -452,3 +452,11 @@ class TestTrackingUtils(object):
         # Test bad extension
         with pytest.raises(ValueError):
             utils.trks_stats('bad-extension.npz')
+
+        # No inputs
+        with pytest.raises(ValueError):
+            utils.trks_stats()
+
+        data = get_dummy_data()
+        stats = utils.trks_stats(**data)
+        assert isinstance(stats, dict)
